Package: survminer
Type: Package
Title: Drawing Survival Curves using 'ggplot2'
Version: 0.5.2
Date: 2026-02-24
Authors@R: c(
    person("Alboukadel", "Kassambara", role = c("aut", "cre"), email = "alboukadel.kassambara@gmail.com"),
    person("Marcin", "Kosinski", role = c("aut"), email = "m.p.kosinski@gmail.com"),
    person("Przemyslaw", "Biecek", role = c("aut"), email = "przemyslaw.biecek@gmail.com"),
    person("Scheipl", "Fabian", role = c("ctb"), email = "fabian.scheipl@gmail.com"))
Description: Contains the function 'ggsurvplot()' for drawing easily beautiful
    and 'ready-to-publish' survival curves with the 'number at risk' table
    and 'censoring count plot'. Other functions are also available to plot 
    adjusted curves for `Cox` model and to visually examine 'Cox' model assumptions.
License: GPL-2
LazyData: TRUE
Encoding: UTF-8
Depends: ggplot2(>= 3.4.0), ggpubr(>= 0.1.6)
Imports: grid, gridExtra (>= 2.0), magrittr, maxstat, methods, scales,
        survival, stats, broom, dplyr, tidyr, purrr, tibble, rlang,
        ggtext (>= 0.1.0)
Suggests: knitr, flexsurv, cmprsk, markdown, testthat, rmarkdown
VignetteBuilder: knitr
URL: https://rpkgs.datanovia.com/survminer/index.html
BugReports: https://github.com/kassambara/survminer/issues
RoxygenNote: 7.3.3
Collate: 'BMT.R' 'BRCAOV.survInfo.R' 'add_ggsurvplot.R' 'utilities.R'
        'surv_summary.R' 'ggsurvtable.R' 'surv_pvalue.R'
        'ggsurvplot_df.R' 'ggsurvplot_core.R' 'ggsurvplot_add_all.R'
        'ggsurvplot_list.R' 'ggsurvplot_group_by.R' 'ggsurvplot.R'
        'arrange_ggsurvplots.R' 'ggadjustedcurves.R'
        'ggcompetingrisks.R' 'ggcoxdiagnostics.R' 'ggcoxfunctional.R'
        'ggcoxzph.R' 'ggflexsurvplot.R' 'ggforest.R' 'ggsurvevents.R'
        'ggsurvplot_combine.R' 'ggsurvplot_facet.R' 'ggsurvtheme.R'
        'ggurvplot_arguments.R' 'myeloma.R' 'pairwise_survdiff.R'
        'surv_cutpoint.R' 'surv_group_by.R' 'surv_fit.R'
        'surv_median.R' 'weighted_logrank.R'
NeedsCompilation: no
Packaged: 2026-02-24 20:15:34 UTC; kassambara
Author: Alboukadel Kassambara [aut, cre],
  Marcin Kosinski [aut],
  Przemyslaw Biecek [aut],
  Scheipl Fabian [ctb]
Maintainer: Alboukadel Kassambara <alboukadel.kassambara@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-25 06:30:14 UTC
Built: R 4.6.0; ; 2026-05-01 05:38:43 UTC; unix
