# Generated by roxygen2: do not edit by hand

S3method("+",ggsurv)
S3method(plot,surv_cutpoint)
S3method(print,ggcoxfunctional)
S3method(print,ggcoxzph)
S3method(print,ggsurvplot)
S3method(print,plot_surv_cutpoint)
S3method(print,surv_cutpoint)
S3method(summary,surv_cutpoint)
export("%++%")
export(arrange_ggsurvplots)
export(ggadjustedcurves)
export(ggcompetingrisks)
export(ggcoxdiagnostics)
export(ggcoxfunctional)
export(ggcoxzph)
export(ggcumcensor)
export(ggcumevents)
export(ggflexsurvplot)
export(ggforest)
export(ggrisktable)
export(ggsurvevents)
export(ggsurvplot)
export(ggsurvplot_add_all)
export(ggsurvplot_combine)
export(ggsurvplot_df)
export(ggsurvplot_facet)
export(ggsurvplot_group_by)
export(ggsurvplot_list)
export(ggsurvtable)
export(pairwise_survdiff)
export(surv_adjustedcurves)
export(surv_categorize)
export(surv_cutpoint)
export(surv_fit)
export(surv_group_by)
export(surv_median)
export(surv_pvalue)
export(surv_summary)
export(theme_cleantable)
export(theme_survminer)
import(broom)
import(ggplot2)
import(ggpubr)
import(grid)
import(gridExtra)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(ggplot2,geom_step)
importFrom(grDevices,axisTicks)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(purrr,map)
importFrom(rlang,"!!")
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(stats,anova)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,lowess)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,resid)
importFrom(stats,residuals)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(survival,survdiff)
importFrom(survival,survexp)
importFrom(survival,survfit)
importFrom(tidyr,gather)
importFrom(utils,capture.output)
